#
# spec file for package netfetch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           netfetch
Version:        0.5.4
Release:        1.1
Summary:        Scanning clusters for network policies and identifying unprotected workloads
License:        MIT
URL:            https://github.com/deggja/netfetch
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
This project aims to demystify network policies in Kubernetes. It's a work in
progress!

The netfetch tool will scan your Kubernetes cluster and let you know if you
have any pods running without being targeted by network policies.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1
%setup -q -D -a 1 -n %{name}-%{version}/backend/

%build
ls -lh
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/deggja/netfetch/backend/cmd.Version=%{version}" \
   -o bin/%{name} ./main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
# working directory is set to backend by the setup macro in pre
%doc ../README.md
%license ../LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.5.4:
  * docs: updated docs for --kubeconfig flag and updated score
    section
  * feat: format output for when kubeconfig is provided
  * feat: add ability to use optional kubeconfig flag to all
    optional commands
  * chore: update index with helm repo index
  * chore: update tgz
  * chore: update helm chart versions
  * chore: update homebrew formula for v0.5.3
  * ci: replace github for create pull request and use github cli
    directly
  * ci: specify token and rearrange parameters
  * ci: debug workflow
  * ci: try force
  * ci: remove fetch
  * ci: remove debug and move pull
  * ci: dont delete branch in workflow
  * ci: branch does not exist yet
  * ci: fetch changes
  * ci: remove redundant steps
  * ci: set base in create pr step
  * ci: remove temp files befoer pulling
  * ci: verify no changes
  * ci: fetch latest changes from main if any
  * ci: update create pull request job
  * ci: adjust formula path
  * ci: add debug step for shasums
  * ci: add prefix
  * ci: use temp dir to not include binaries in prs
  * ci: specify to create branch and author details
  * ci: adjust formula path in workflow
  * ci: debug workflow extracting version
  * ci: add workflow to update homebrew
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- use correct version number (the one for the CLI, not the helm
  chart)
- Update to version 0.5.3:
  * ci: remove hooks, duplicate
  * ci: update goreleaser and release workflow
  * ci: refactor release process using goreleaser
* Sun Sep 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.2.10:
  * chore: comment out WIP scoring and prepare release #patch
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.2.9:
  * ci: use bump_version.sh
  * chore: remove debugging
  * chore: remove unused values
  * chore: remove unused parameter from determinePodCoverage
  * fix: ensure pods are only added to lists once
  * ci: update release workflow
  * feat: update calculate score test
  * feat: add description of scan when running cilium namespaced
    scans
  * feat: update top score
  * feat: update scoring logic
* Mon Jun 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 5.2.8 (no releases between 5.2.5 and this one):
  * docs: edit cobra command for netfetch #patch
  * ci: set goreleaser version to 2
  * ci: add manual trigger to workflow
  * ci: remove unknown flag from goreleaser worklflow
  * docs: added comments in code for fix #107 #patch
  * fix: update cilium scanners to only check running pods
  * fix: update native scanner to check for running pods only
  * chore: add gitignore so test binary wont be pushed
  * chore: update brew shasums
* Wed Jun 12 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package netfetch: Kubernetes tool for scanning clusters for
  network policies and identifying unprotected workloads
